@@ -1023,7 +1023,7 @@ class WordToken(caching.base.CachingMixin,models.Model):
                 return True
         return False
 
-    def nextToPause(self):
+    def next_to_pause(self):
         if self.after_pause():
             return True
         if self.before_pause():
@@ -1112,9 +1112,7 @@ class WordToken(caching.base.CachingMixin,models.Model):
         #spectrogram.render().save(specpath)
 
     def is_acceptable(self):
-        if self.nextToPause():
-            return False
-        if len(self.WordType.getCVSkel()) < 3:
+        if self.next_to_pause():
             return False
         return True
 
